@@ -75,7 +75,7 @@ Note: getTempName() and getCompNames() create the directories, if needed, so fil
 
 Note: all file names are absolute.
 
-//ttt1 option to remove the original file, once it's pretty sure that the changes the program makes are consistently good
+
 
 //ttt2 more options to change what getBackupName() and getDestName() return and some other things:
     1) the name can be the original one or changed;
@@ -88,7 +88,7 @@ Note: all file names are absolute.
 class TransfConfig
 {
     //bool m_bRename
-    std::string m_strSrcDir; // all scanned files are supposed to be here; // 2009.04.08 - for now it seems better to force this to be empty, by not allowing it to be edited // ttt1 perhaps put back, or calculate it from a session's folders in saveTransfConfig(), but seems likely to create confusion; can be edited manually in the config file to see what it does (or by commenting out "m_pSourceDirF->hide()")
+    std::string m_strSrcDir; // all scanned files are supposed to be here; // 2009.04.08 - for now it seems better to force this to be empty, by not allowing it to be edited // ttt2 perhaps put back, or calculate it from a session's folders in saveTransfConfig(), but seems likely to create confusion; can be edited manually in the config file to see what it does (or by commenting out "m_pSourceDirF->hide()")
     std::string m_strProcOrigDir;
     std::string m_strUnprocOrigDir;
     std::string m_strProcessedDir;
@@ -142,9 +142,14 @@ class TransfConfig
     //
     //----------------------------
     //
-    //  16: 0 = don't comp files
+    //  16: 0 = don't create comp files
     //      1 = create comp files in m_strCompDir
     //
+    //----------------------------
+    //
+    //  17: 0 = keep orig time
+    //      1 = don't keep orig time
+    //
     /*int m_nOptions;
 
     int getOpt(int nStartBit, int nCount) const { return (m_nOptions >> nStartBit) & ((1 << nCount) - 1); }*/
@@ -174,17 +179,33 @@ public:
     TransfConfig();
 
 
-    struct Options
+    class Options
     {
-        unsigned m_nProcOrigChange : 3;
+    public:
+        enum ProcOrig { PO_DONT_CHG, PO_ERASE, PO_MOVE_ALWAYS_RENAME, PO_MOVE_RENAME_IF_USED, PO_RENAME_SAME_DIR, PO_MOVE_OR_ERASE };
+        enum UnprocOrig { UPO_DONT_CHG, UPO_ERASE, UPO_MOVE_ALWAYS_RENAME, UPO_MOVE_RENAME_IF_USED, UPO_RENAME_SAME_DIR }; // !!! the values in UnprocOrig must match those in ProcOrig for getChangedOrigNameHlp() to work correctly
+        enum Processed { PR_DONT_CREATE, PR_CREATE_ALWAYS_RENAME, PR_CREATE_RENAME_IF_USED };
+
+    private:
+        static unsigned uns(bool b) { return b ? 1 : 0; }
+        static unsigned uns(unsigned x) { return x; }
+        static unsigned uns(ProcOrig x) { return x; }
+        static unsigned uns(UnprocOrig x) { return x; }
+        static unsigned uns(Processed x) { return x; }
+
+    public:
+
+        Options(); // initializes the fields to a "non-backup" state
+
+        ProcOrig m_eProcOrigChange : 4; // !!! really "3", but declares more bits than used to avoid issues with signed/unsigned enums
         bool m_bProcOrigUseLabel : 1;
         bool m_bProcOrigAlwayUseCounter : 1;
 
-        unsigned m_nUnprocOrigChange : 3;
+        UnprocOrig m_eUnprocOrigChange : 4; // !!! really "3", but declares more bits than used to avoid issues with signed/unsigned enums
         bool m_bUnprocOrigUseLabel : 1;
         bool m_bUnprocOrigAlwayUseCounter : 1;
 
-        unsigned m_nProcessedCreate : 2;
+        Processed m_eProcessedCreate : 3; // !!! really "2", but declares more bits than used to avoid issues with signed/unsigned enums
         bool m_bProcessedUseLabel : 1;
         bool m_bProcessedAlwayUseCounter : 1;
         bool m_bProcessedUseSeparateDir : 1;
@@ -194,15 +215,68 @@ public:
         bool m_bCompCreate : 1;
 
         bool m_bKeepOrigTime : 1;
+
+
+        int getVal() const
+        {
+            unsigned x (0); unsigned s (0);
+
+            x ^= (uns(m_eProcOrigChange) << s); s += 3; // unsigned m_nProcOrigChange : 3;
+            x ^= (uns(m_bProcOrigUseLabel) << s); s += 1; // bool m_bProcOrigUseLabel : 1;
+            x ^= (uns(m_bProcOrigAlwayUseCounter) << s); s += 1; // bool m_bProcOrigAlwayUseCounter : 1;
+
+            x ^= (uns(m_eUnprocOrigChange) << s); s += 3; // unsigned m_nUnprocOrigChange : 3;
+            x ^= (uns(m_bUnprocOrigUseLabel) << s); s += 1; // bool m_bUnprocOrigUseLabel : 1;
+            x ^= (uns(m_bUnprocOrigAlwayUseCounter) << s); s += 1; // bool m_bUnprocOrigAlwayUseCounter : 1;
+
+            x ^= (uns(m_eProcessedCreate) << s); s += 2; // unsigned m_nProcessedCreate : 2;
+            x ^= (uns(m_bProcessedUseLabel) << s); s += 1; // bool m_bProcessedUseLabel : 1;
+            x ^= (uns(m_bProcessedAlwayUseCounter) << s); s += 1; // bool m_bProcessedAlwayUseCounter : 1;
+            x ^= (uns(m_bProcessedUseSeparateDir) << s); s += 1; // bool m_bProcessedUseSeparateDir : 1;
+
+            x ^= (uns(m_bTempCreate) << s); s += 1; // bool m_bTempCreate : 1;
+
+            x ^= (uns(m_bCompCreate) << s); s += 1; // bool m_bCompCreate : 1;
+
+            x ^= (uns(m_bKeepOrigTime) << s); s += 1; // bool m_bKeepOrigTime : 1;
+
+            return int(x);
+        }
+
+        void setVal(int x)
+        {
+            m_eProcOrigChange = ProcOrig(x & 0x07); x >>= 3; // unsigned m_nProcOrigChange : 3;
+            m_bProcOrigUseLabel = x & 0x01; x >>= 1; // bool m_bProcOrigUseLabel : 1;
+            m_bProcOrigAlwayUseCounter = x & 0x01; x >>= 1; // bool m_bProcOrigAlwayUseCounter : 1;
+
+            m_eUnprocOrigChange = UnprocOrig(x & 0x07); x >>= 3; // unsigned m_nUnprocOrigChange : 3;
+            m_bUnprocOrigUseLabel = x & 0x01; x >>= 1; // bool m_bUnprocOrigUseLabel : 1;
+            m_bUnprocOrigAlwayUseCounter = x & 0x01; x >>= 1; // bool m_bUnprocOrigAlwayUseCounter : 1;
+
+            m_eProcessedCreate = Processed(x & 0x03); x >>= 2; // unsigned m_nProcessedCreate : 2;
+            m_bProcessedUseLabel = x & 0x01; x >>= 1; // bool m_bProcessedUseLabel : 1;
+            m_bProcessedAlwayUseCounter = x & 0x01; x >>= 1; // bool m_bProcessedAlwayUseCounter : 1;
+            m_bProcessedUseSeparateDir = x & 0x01; x >>= 1; // bool m_bProcessedUseSeparateDir : 1;
+
+            m_bTempCreate = x & 0x01; x >>= 1; // bool m_bTempCreate : 1;
+
+            m_bCompCreate = x & 0x01; x >>= 1; // bool m_bCompCreate : 1;
+
+            m_bKeepOrigTime = x & 0x01; x >>= 1; // bool m_bKeepOrigTime : 1;
+        }
+
+        bool operator==(const Options& opt) const
+        {
+            return getVal() == opt.getVal();
+        }
+
+        // backup is 3-state; based on various fields, options may be "backup", "non-backup", or neither of them
+        Options asBackup() const; // returns *this, with some fields changed to match a "backup" configuration; touches many field, but ignores others (m_bProcOrigUseLabel, m_bProcOrigAlwayUseCounter, m_bUnprocOrigUseLabel, m_bUnprocOrigAlwayUseCounter, m_bKeepOrigTime)
+        Options asNonBackup() const; // returns *this, with some fields changed to match a "non-backup" configuration; touches many field, but ignores others (m_bProcOrigUseLabel, m_bProcOrigAlwayUseCounter, m_bUnprocOrigUseLabel, m_bUnprocOrigAlwayUseCounter, m_bKeepOrigTime)
     };
 
-    union OptionsWrp
-    {
-        int m_nVal;
-        Options m_opt;
-    };
+    Options m_options;
 
-    OptionsWrp m_optionsWrp;
 /*
     // the name for an "intermediate" file; it's obtained from the "temp dir" and from the short name of the original file, with a ".temp.<NNN>" inserted before the extension, where <NNN> is a number chosen such that a file with this new name doesn't exist;
     std::string getTempName(const std::string& strOrigSrcName, const std::string& strOpName) const;
@@ -246,9 +320,11 @@ public:
     const std::string& getTempDir() const { return m_strTempDir; }
     const std::string& getCompDir() const { return m_strCompDir; }
 
-    void setProcOrigDir(const std::string& s) { m_strProcOrigDir = s; } // needed by the session dialog //ttt1 perhaps some checks
+    void setProcOrigDir(const std::string& s) { m_strProcOrigDir = s; } // needed by the session dialog //ttt2 perhaps some checks
 
-    int getOptions() const { return m_optionsWrp.m_nVal; }
+    int getOptions() const { return m_options.getVal(); }
+
+    bool hadInitError() const { return m_bInitError; }
 
     //struct DirOverlap {};
     //struct InvalidName {}; // something is wrong with the file name
@@ -256,8 +332,9 @@ public:
 
     void testRemoveSuffix() const;
 private:
-    OrigFile getChangedOrigNameHlp(const std::string& strOrigSrcName, const std::string& strDestDir, int nChange, bool bUseLabel, bool bAlwayUseCounter, std::string& strNewName) const;
+    OrigFile getChangedOrigNameHlp(const std::string& strOrigSrcName, const std::string& strDestDir, int nChange, bool bUseLabel, bool bAlwayUseCounter, std::string& strNewName) const; // !!! nChange will get initialized from either ProcOrig or UnprocOrig, so their values must match
     void removeSuffix(std::string& s) const;
+    bool m_bInitError;
 };
 
 
@@ -275,9 +352,12 @@ public:
     static Result CHANGED_NO_RECALL;*/
 
     virtual Result apply(const Mp3Handler&, const TransfConfig&, const std::string& strOrigSrcName, std::string& strTempName) = 0; // this may throw
-    virtual const char* getActionName() const = 0;
+    virtual const char* getActionName() const = 0; // should return the same thing for all objects of a class, as this is used in string comparisons in several places (visible transformations, custom transformation lists, ...)
+    virtual const char* getVisibleActionName() const { return getActionName(); } // to be used only by the UI, providing more details to the user
     virtual const char* getDescription() const = 0;
 
+    virtual bool acceptsFastSave() const { return false; } // whether to consider Mp3Handler::m_nFastSaveTime as a match when deciding if a file was changed (so a transformation can't be applied)
+
     struct InvalidInputFile {}; // thrown if the input file was changed so it can no longer be processed
 };
 
